# Contributors

We are grateful to everyone who has contributed to Bernstein.

## Core team

- **Alex Chernysh** ([@chernistry](https://github.com/chernistry)) — Creator, core maintenance

## Community

Bernstein is open-source under the Apache 2.0 license. We welcome all contributions — bug fixes, docs improvements, new adapters, features, and bug reports. See [CONTRIBUTING.md](CONTRIBUTING.md) for how to get started.

The [full list of contributors](https://github.com/chernistry/bernstein/graphs/contributors) is maintained by GitHub.
